@@ -5,6 +5,7 @@ from typing import Any, Dict, Iterable, List
 
 import botocore.client
 import loguru
+from botocore.response import StreamingBody
 
 from dai_python_commons import dai_error
 
@@ -220,3 +221,18 @@ class S3Utils:
             raise Exception(error_info.get("Message", ""))
 
         return response["LastModified"]
+
+    @staticmethod
+    def read_s3_file(s3_client, bucket_name: str, key: str) -> StreamingBody:
+        """
+        Get content of an S3 object
+
+        :param s3_client: Boto3 s3 client
+        :param bucket_name: Name of s3 bucket
+        :param key: Object key
+        :return: Http response body
+        """
+        response = s3_client.get_object(Bucket=bucket_name, Key=key)
+        content = response["Body"]
+
+        return content
